@@ -31,6 +31,8 @@
 
 G_BEGIN_DECLS
 
+#define PANEL_MAIN_MENU_ICON "gnome-main-menu"
+
 #define PANEL_TYPE_MENU_BUTTON         (panel_menu_button_get_type ())
 #define PANEL_MENU_BUTTON(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), PANEL_TYPE_MENU_BUTTON, PanelMenuButton))
 #define PANEL_MENU_BUTTON_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), PANEL_TYPE_MENU_BUTTON, PanelMenuButtonClass))
@@ -54,15 +56,19 @@ struct _PanelMenuButtonClass {
 
 GType      panel_menu_button_get_type            (void) G_GNUC_CONST;
 
-void       panel_menu_button_create              (PanelToplevel    *toplevel,
+gboolean   panel_menu_button_create              (PanelToplevel    *toplevel,
 						  int               position,
+						  const char       *filename,
 						  const char       *menu_path,
-						  gboolean          use_menu_path);
+						  gboolean          use_menu_path,
+						  const char       *tooltip);
 
 void       panel_menu_button_set_menu_path       (PanelMenuButton  *button,
 						  const char       *menu_path);
 void       panel_menu_button_set_custom_icon     (PanelMenuButton  *button,
 						  const char       *custom_icon);
+void       panel_menu_button_set_tooltip         (PanelMenuButton *button,
+						  const char      *tooltip);
 void       panel_menu_button_set_use_menu_path   (PanelMenuButton  *button,
 						  gboolean          use_menu_path);
 gboolean   panel_menu_button_get_use_menu_path   (PanelMenuButton  *button);
@@ -85,9 +91,6 @@ void       panel_menu_button_popup_menu          (PanelMenuButton  *button,
 						  guint             n_button,
 						  guint32           activate_time);
 
-void       panel_menu_button_change_orientation  (PanelMenuButton  *button,
-						  PanelOrientation  orientation);
-
 void       panel_menu_button_set_dnd_enabled     (PanelMenuButton  *button,
 						  gboolean          dnd_enabled);
 
