@@ -113,10 +113,7 @@ panel_recent_model_changed_cb (EggRecentModel *model,
                                GList          *list,
                                GtkWidget      *menu_item)
 {
-	GList *recent_list = NULL;
-
-	recent_list = egg_recent_model_get_list (model);
-	if (recent_list)
+	if (list)
 		gtk_widget_set_sensitive (menu_item, TRUE);
 	else
 		gtk_widget_set_sensitive (menu_item, FALSE);
@@ -237,6 +234,7 @@ panel_recent_append_documents_menu (GtkWidget *top_menu)
 				 menu_item, 0);
 
 	view = egg_recent_view_gtk_new (menu, NULL);
+	g_object_unref (G_OBJECT (menu));
 
 	egg_recent_view_gtk_set_tooltip_func (view,
 					      recent_documents_tooltip_func,
